Uses equations for mean and variance of chain size from Waxman and Nouvellet(https://doi.org/10.1016/j.jtbi.2019.01.033)

nbbp_stats(r, k)

Arguments

r

effective reproduction number

k

dispersion parameter

Value

named vector providing the (conditioned on there being a finite chain size, i.e. on extinction) mean and variance of the final size.